@@ -22,11 +22,11 @@ THE SOFTWARE.
 
 """
 
+import logging
 from collections import deque, namedtuple, Counter
 
 import cocotb
 from cocotb.triggers import Event
-from cocotb.log import SimLog
 
 from .version import __version__
 from .constants import AxiBurstType, AxiLockType, AxiProt, AxiResp
@@ -49,7 +49,7 @@ AxiReadResp = namedtuple("AxiReadResp", ["address", "data", "resp", "user"])
 
 class AxiMasterWrite(object):
     def __init__(self, entity, name, clock, reset=None, max_burst_len=256):
-        self.log = SimLog("cocotb.%s.%s" % (entity._name, name))
+        self.log = logging.getLogger(f"cocotb.{entity._name}.{name}")
 
         self.log.info("AXI master (write)")
         self.log.info("cocotbext-axi version %s", __version__)
@@ -297,7 +297,7 @@ class AxiMasterWrite(object):
                     else:
                         w.wuser = 0
 
-                self.w_channel.send(w)
+                await self.w_channel.send(w)
 
                 cur_addr += num_bytes
                 cycle_offset = (cycle_offset + num_bytes) % self.byte_width
@@ -318,17 +318,15 @@ class AxiMasterWrite(object):
             user = []
 
             for bid, burst_length in cmd.burst_list:
-                while True:
-                    if self.int_write_resp_queue_list[bid]:
-                        break
+                while not self.int_write_resp_queue_list[bid]:
+                    b = await self.b_channel.recv()
 
-                    await self.b_channel.wait()
-                    b = self.b_channel.recv()
+                    i = int(b.bid)
 
-                    if self.active_id[int(b.bid)] <= 0:
+                    if self.active_id[i] <= 0:
                         raise Exception(f"Unexpected burst ID {bid}")
 
-                    self.int_write_resp_queue_list[int(b.bid)].append(b)
+                    self.int_write_resp_queue_list[i].append(b)
 
                 b = self.int_write_resp_queue_list[bid].popleft()
 
@@ -365,7 +363,7 @@ class AxiMasterWrite(object):
 
 class AxiMasterRead(object):
     def __init__(self, entity, name, clock, reset=None, max_burst_len=256):
-        self.log = SimLog("cocotb.%s.%s" % (entity._name, name))
+        self.log = logging.getLogger(f"cocotb.{entity._name}.{name}")
 
         self.log.info("AXI master (read)")
         self.log.info("cocotbext-axi version %s", __version__)
@@ -598,17 +596,15 @@ class AxiMasterRead(object):
 
             for rid, burst_length in cmd.burst_list:
                 for k in range(burst_length):
-                    while True:
-                        if self.int_read_resp_queue_list[rid]:
-                            break
+                    while not self.int_read_resp_queue_list[rid]:
+                        r = await self.r_channel.recv()
 
-                        await self.r_channel.wait()
-                        r = self.r_channel.recv()
+                        i = int(r.rid)
 
-                        if self.active_id[int(r.rid)] <= 0:
+                        if self.active_id[i] <= 0:
                             raise Exception(f"Unexpected burst ID {rid}")
 
-                        self.int_read_resp_queue_list[int(r.rid)].append(r)
+                        self.int_read_resp_queue_list[i].append(r)
 
                     r = self.int_read_resp_queue_list[rid].popleft()
 
